### FEIOS_UTILS
* This is a library for feios to run.
* This includes some small and useful utils.
* You can use it in your app like:
```python
import feios_utils
feios_utils.out("Hello")
```
* Note that the library is licensed under GNU GPL v3+.Your app should be licensed under that too.

=========================

### Changelog
#### 0.3.0dev1
* Added full support for exts.
#### 0.2.0post1
* Fixed CVE-002:DevStatusError.
#### 0.2.0
* Added support again for exts.
#### 0.2.0b4
* Added support for exts.
#### Changelog @ 0.2.0b3
* Finally fixed IndexError.
* deleted 'egg' support.
#### Changelog @ 0.2.0b2
* added legacy "egg" dist
#### Changelog @ 0.2.0b1
* Again fixed corrupt IndexError in funcs.run,since last fix is not successful.
#### Changelog @ 0.2.0a2
* Fixed corrupt IndexError in funcs.run.
#### Changelog @ 0.2.0a1
* no change (huh)
#### Changelog @ 0.2.0.dev3
* Added support back to py3.5.
#### Changelog @ 0.2.0.dev2
* Added load_cmd for **later** use.
